pub struct EndpointOnCompletionRequest {
pub completion: Vec<Completion>,
}Fields
completion: Vec<Completion>Trait Implementations
Sourceimpl Debug for EndpointOnCompletionRequest
impl Debug for EndpointOnCompletionRequest
Sourceimpl Decode<EndpointOnCompletionRequest, DefaultFuchsiaResourceDialect> for EndpointOnCompletionRequest
impl Decode<EndpointOnCompletionRequest, DefaultFuchsiaResourceDialect> for EndpointOnCompletionRequest
Sourceimpl Encode<EndpointOnCompletionRequest, DefaultFuchsiaResourceDialect> for &mut EndpointOnCompletionRequest
impl Encode<EndpointOnCompletionRequest, DefaultFuchsiaResourceDialect> for &mut EndpointOnCompletionRequest
Sourceimpl<T0: Encode<Vector<Completion, 300>, DefaultFuchsiaResourceDialect>> Encode<EndpointOnCompletionRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<Vector<Completion, 300>, DefaultFuchsiaResourceDialect>> Encode<EndpointOnCompletionRequest, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl PartialEq for EndpointOnCompletionRequest
impl PartialEq for EndpointOnCompletionRequest
Sourcefn eq(&self, other: &EndpointOnCompletionRequest) -> bool
fn eq(&self, other: &EndpointOnCompletionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ResourceTypeMarker for EndpointOnCompletionRequest
impl ResourceTypeMarker for EndpointOnCompletionRequest
Sourcetype Borrowed<'a> = &'a mut EndpointOnCompletionRequest
type Borrowed<'a> = &'a mut EndpointOnCompletionRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for EndpointOnCompletionRequest
impl StructuralPartialEq for EndpointOnCompletionRequest
Sourceimpl TypeMarker for EndpointOnCompletionRequest
impl TypeMarker for EndpointOnCompletionRequest
Sourcetype Owned = EndpointOnCompletionRequest
type Owned = EndpointOnCompletionRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for EndpointOnCompletionRequest
impl RefUnwindSafe for EndpointOnCompletionRequest
impl Send for EndpointOnCompletionRequest
impl Sync for EndpointOnCompletionRequest
impl Unpin for EndpointOnCompletionRequest
impl UnsafeUnpin for EndpointOnCompletionRequest
impl UnwindSafe for EndpointOnCompletionRequest