pub struct EndpointQueueRequestsRequest {
pub req: Vec<Request>,
}Fields
req: Vec<Request>Trait Implementations
Sourceimpl Debug for EndpointQueueRequestsRequest
impl Debug for EndpointQueueRequestsRequest
Sourceimpl Decode<EndpointQueueRequestsRequest, DefaultFuchsiaResourceDialect> for EndpointQueueRequestsRequest
impl Decode<EndpointQueueRequestsRequest, DefaultFuchsiaResourceDialect> for EndpointQueueRequestsRequest
Sourceimpl Encode<EndpointQueueRequestsRequest, DefaultFuchsiaResourceDialect> for &mut EndpointQueueRequestsRequest
impl Encode<EndpointQueueRequestsRequest, DefaultFuchsiaResourceDialect> for &mut EndpointQueueRequestsRequest
Sourceimpl<T0: Encode<Vector<Request, 300>, DefaultFuchsiaResourceDialect>> Encode<EndpointQueueRequestsRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<Vector<Request, 300>, DefaultFuchsiaResourceDialect>> Encode<EndpointQueueRequestsRequest, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl PartialEq for EndpointQueueRequestsRequest
impl PartialEq for EndpointQueueRequestsRequest
Sourcefn eq(&self, other: &EndpointQueueRequestsRequest) -> bool
fn eq(&self, other: &EndpointQueueRequestsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ResourceTypeMarker for EndpointQueueRequestsRequest
impl ResourceTypeMarker for EndpointQueueRequestsRequest
Sourcetype Borrowed<'a> = &'a mut EndpointQueueRequestsRequest
type Borrowed<'a> = &'a mut EndpointQueueRequestsRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for EndpointQueueRequestsRequest
impl StructuralPartialEq for EndpointQueueRequestsRequest
Sourceimpl TypeMarker for EndpointQueueRequestsRequest
impl TypeMarker for EndpointQueueRequestsRequest
Sourcetype Owned = EndpointQueueRequestsRequest
type Owned = EndpointQueueRequestsRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for EndpointQueueRequestsRequest
impl RefUnwindSafe for EndpointQueueRequestsRequest
impl Send for EndpointQueueRequestsRequest
impl Sync for EndpointQueueRequestsRequest
impl Unpin for EndpointQueueRequestsRequest
impl UnsafeUnpin for EndpointQueueRequestsRequest
impl UnwindSafe for EndpointQueueRequestsRequest