pub struct EndpointRegisterVmosResponse {
pub vmos: Vec<VmoHandle>,
}Fields
vmos: Vec<VmoHandle>Trait Implementations
Sourceimpl Debug for EndpointRegisterVmosResponse
impl Debug for EndpointRegisterVmosResponse
Sourceimpl Decode<EndpointRegisterVmosResponse, DefaultFuchsiaResourceDialect> for EndpointRegisterVmosResponse
impl Decode<EndpointRegisterVmosResponse, DefaultFuchsiaResourceDialect> for EndpointRegisterVmosResponse
Sourceimpl Encode<EndpointRegisterVmosResponse, DefaultFuchsiaResourceDialect> for &mut EndpointRegisterVmosResponse
impl Encode<EndpointRegisterVmosResponse, DefaultFuchsiaResourceDialect> for &mut EndpointRegisterVmosResponse
Sourceimpl<T0: Encode<Vector<VmoHandle, 300>, DefaultFuchsiaResourceDialect>> Encode<EndpointRegisterVmosResponse, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<Vector<VmoHandle, 300>, DefaultFuchsiaResourceDialect>> Encode<EndpointRegisterVmosResponse, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl PartialEq for EndpointRegisterVmosResponse
impl PartialEq for EndpointRegisterVmosResponse
Sourcefn eq(&self, other: &EndpointRegisterVmosResponse) -> bool
fn eq(&self, other: &EndpointRegisterVmosResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ResourceTypeMarker for EndpointRegisterVmosResponse
impl ResourceTypeMarker for EndpointRegisterVmosResponse
Sourcetype Borrowed<'a> = &'a mut EndpointRegisterVmosResponse
type Borrowed<'a> = &'a mut EndpointRegisterVmosResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for EndpointRegisterVmosResponse
impl StructuralPartialEq for EndpointRegisterVmosResponse
Sourceimpl TypeMarker for EndpointRegisterVmosResponse
impl TypeMarker for EndpointRegisterVmosResponse
Sourcetype Owned = EndpointRegisterVmosResponse
type Owned = EndpointRegisterVmosResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for EndpointRegisterVmosResponse
impl RefUnwindSafe for EndpointRegisterVmosResponse
impl Send for EndpointRegisterVmosResponse
impl Sync for EndpointRegisterVmosResponse
impl Unpin for EndpointRegisterVmosResponse
impl UnsafeUnpin for EndpointRegisterVmosResponse
impl UnwindSafe for EndpointRegisterVmosResponse