pub struct EndpointUnregisterVmosResponse {
pub failed_vmo_ids: Vec<u64>,
pub errors: Vec<i32>,
}Fields
failed_vmo_ids: Vec<u64>errors: Vec<i32>Trait Implementations
Sourceimpl Decode<EndpointUnregisterVmosResponse, DefaultFuchsiaResourceDialect> for EndpointUnregisterVmosResponse
impl Decode<EndpointUnregisterVmosResponse, DefaultFuchsiaResourceDialect> for EndpointUnregisterVmosResponse
Sourceimpl Encode<EndpointUnregisterVmosResponse, DefaultFuchsiaResourceDialect> for &mut EndpointUnregisterVmosResponse
impl Encode<EndpointUnregisterVmosResponse, DefaultFuchsiaResourceDialect> for &mut EndpointUnregisterVmosResponse
Sourceimpl<T0: Encode<Vector<u64, 300>, DefaultFuchsiaResourceDialect>, T1: Encode<Vector<i32, 300>, DefaultFuchsiaResourceDialect>> Encode<EndpointUnregisterVmosResponse, DefaultFuchsiaResourceDialect> for (T0, T1)
impl<T0: Encode<Vector<u64, 300>, DefaultFuchsiaResourceDialect>, T1: Encode<Vector<i32, 300>, DefaultFuchsiaResourceDialect>> Encode<EndpointUnregisterVmosResponse, DefaultFuchsiaResourceDialect> for (T0, T1)
impl Eq for EndpointUnregisterVmosResponse
Sourceimpl Ord for EndpointUnregisterVmosResponse
impl Ord for EndpointUnregisterVmosResponse
Sourcefn cmp(&self, other: &EndpointUnregisterVmosResponse) -> Ordering
fn cmp(&self, other: &EndpointUnregisterVmosResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EndpointUnregisterVmosResponse
impl PartialEq for EndpointUnregisterVmosResponse
Sourcefn eq(&self, other: &EndpointUnregisterVmosResponse) -> bool
fn eq(&self, other: &EndpointUnregisterVmosResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for EndpointUnregisterVmosResponse
impl PartialOrd for EndpointUnregisterVmosResponse
Sourceimpl ResourceTypeMarker for EndpointUnregisterVmosResponse
impl ResourceTypeMarker for EndpointUnregisterVmosResponse
Sourcetype Borrowed<'a> = &'a mut EndpointUnregisterVmosResponse
type Borrowed<'a> = &'a mut EndpointUnregisterVmosResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for EndpointUnregisterVmosResponse
impl StructuralPartialEq for EndpointUnregisterVmosResponse
Sourceimpl TypeMarker for EndpointUnregisterVmosResponse
impl TypeMarker for EndpointUnregisterVmosResponse
Sourcetype Owned = EndpointUnregisterVmosResponse
type Owned = EndpointUnregisterVmosResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for EndpointUnregisterVmosResponse
impl RefUnwindSafe for EndpointUnregisterVmosResponse
impl Send for EndpointUnregisterVmosResponse
impl Sync for EndpointUnregisterVmosResponse
impl Unpin for EndpointUnregisterVmosResponse
impl UnsafeUnpin for EndpointUnregisterVmosResponse
impl UnwindSafe for EndpointUnregisterVmosResponse